@@ -1,8 +1,9 @@
-from act.scio.plugin import BasePlugin, Result
-import addict
-from typing import Text, List, Dict, Set
-import ipaddress
 import re
+from typing import List, Text
+
+import addict
+
+from act.scio.plugin import BasePlugin, Result
 
 
 class Plugin(BasePlugin):
@@ -11,8 +12,8 @@ class Plugin(BasePlugin):
     version = "0.1"
     dependencies: List[Text] = []
 
-    cve = re.compile("\\b(?:CVE|cve)-\d{4}-\d{4,7}\\b")
-    msid = re.compile("\\b(?:MS|ms)\d{2}-\d+\\b")
+    cve = re.compile(r"\b(?:CVE|cve)-\d{4}-\d{4,7}\b")
+    msid = re.compile(r"\b(?:MS|ms)\d{2}-\d+\b")
 
     async def analyze(self, nlpdata: addict.Dict) -> Result:
 
@@ -24,4 +25,3 @@ class Plugin(BasePlugin):
         res.msid = self.msid.findall(text)
 
         return Result(name=self.name, version=self.version, result=res)
-
